﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Ganges.CTI.Library;

namespace GangesCTISample
{
    /// <summary>
    /// MainWindow.xaml の相互作用ロジック
    /// </summary>
    public partial class MainWindow : Window
    {

        public CTIManager ctiManager;
        public MainWindow()
        {
            InitializeComponent();
        }

        private void StartCTI_Button_Click(object sender, RoutedEventArgs e)
        {
            ctiManager = new Ganges.CTI.Library.CTIManager(this.Dispatcher);
            ctiManager.PhoneCalled += CtiPhoneCalled;
            ctiManager.PhoneDetailCalled += CtiPhoneDetailCalled;
            ctiManager.StartCTI();
        }

        private void StopCTIButton_Click(object sender, RoutedEventArgs e)
        {
            ctiManager.StopCTI();
        }

        private void Window_Closed(object sender, EventArgs e)
        {
            try
            {
                if (ctiManager != null)
                {
                    ctiManager.PhoneCalled -= CtiPhoneCalled;
                    ctiManager.PhoneDetailCalled -= CtiPhoneDetailCalled;
                    ctiManager.StopCTI();
                }
            }
            catch (Exception)
            {

            }
        }

        private void CtiPhoneCalled(object sender, Ganges.CTI.Library.CTIInfo info)
        {

            string text = string.Format("連番:{0}\r\n日付:{1}\r\n着信電話番号:{2}\r\n着信電話番号（表示用）:{3}\r\n受信側電話番号:{4}",
                     info.SerialNumber,
                     info.DateTime.ToString(),
                     info.Tel,
                      info.FormedTel,
                     info.ReceiverTel
                     );


            var newNotify = new Notify();
            newNotify.SetText(text);
            newNotify.Show();


            //this.Dispatcherを指定せず、new Ganges.CTI.Library.CTIManager()で、CTIManagerを作成した時、
            //Dispatcherの処理をしないと、ウインドウは表示されない、場合がある。
            //App.Current.Dispatcher.Invoke(new Action(() =>
            //{
            //    var newNotify = new Notify();
            //    newNotify.SetText(text);
            //    newNotify.Show();
            //}
            //));


        }

        private void CtiPhoneDetailCalled(object sender, Ganges.CTI.Library.CTIObj obj)
        {


            foreach (var item in obj.CTIDetailCollection)
            {

                string text = string.Format("連番:{0}\r\nNo:{1}\r\n分類:{2}\r\n団体:{3}\r\n名前:{4}\r\n住所:{5}\r\nType:{6}\r\nEx1:{7}\r\n日付:{8}\r\n着信電話番号:{9}\r\n着信電話番号（表示用）:{10}\r\n受信側電話番号:{11}",
                        item.SerialNumber,
                        item.No,
                        item.Category,
                        item.Group,
                        item.Name,
                        item.Address,
                        item.Type,
                        item.Ex1,
                        item.DateTime.ToString(),
                        item.Tel,
                         item.FormedTel,
                        item.ReceiverTel
                       );

                var newNotify = new Notify();
                newNotify.SetText(text);
                newNotify.Show();

                //App.Current.Dispatcher.Invoke(new Action(() =>
                // {
                //     var newNotify = new Notify();
                //     newNotify.SetText(text);
                //     newNotify.Show();
                // }
                //));
            }
        }

    }
}
